djmessenger.migrations package — djmessenger 1.1.0 documentation

# djmessenger.migrations package

## Submodules

## djmessenger.migrations.0001_initial module

class `djmessenger.migrations.0001_initial.` `Migration`(name, app_label)

  Bases: `django.db.migrations.migration.Migration`

  `dependencies` = []
  `initial` = True
  `operations` = [<CreateModel name='Greetings', fields=[('text', <django.db.models.fields.CharField>)], bases=(<class 'django.db.models.base.Model'>, <class 'djmessenger.utils.serializable.Serializable'>)>]

## djmessenger.migrations.0002_callback_fbuserprofile_getstartedbutton_persistentmenu module

class `djmessenger.migrations.0002_callback_fbuserprofile_getstartedbutton_persistentmenu.` `Migration`(name, app_label)

  Bases: `django.db.migrations.migration.Migration`

  `dependencies` = [('djmessenger', '0001_initial')]
  `operations` = [<CreateModel name='Callback', fields=[('id', <django.db.models.fields.AutoField>)]>, <CreateModel name='FBUserProfile', fields=[('psid', <django.db.models.fields.CharField>), ('first_name', <django.db.models.fields.CharField>), ('last_name', <django.db.models.fields.CharField>), ('profile_pic', <django.db.models.fields.TextField>), ('locale', <django.db.models.fields.CharField>), ('timezone', <django.db.models.fields.SmallIntegerField>), ('gender', <django.db.models.fields.CharField>), ('is_active', <django.db.models.fields.BooleanField>), ('date_joined', <django.db.models.fields.DateTimeField>)]>, <CreateModel name='GetStartedButton', fields=[('payload', <django.db.models.fields.CharField>)]>, <CreateModel name='PersistentMenu', fields=[('id', <django.db.models.fields.AutoField>), ('type', <django.db.models.fields.CharField>), ('title', <django.db.models.fields.CharField>), ('url', <django.db.models.fields.URLField>), ('payload', <django.db.models.fields.CharField>)]>]

## djmessenger.migrations.0003_userlocation module

class `djmessenger.migrations.0003_userlocation.` `Migration`(name, app_label)

  Bases: `django.db.migrations.migration.Migration`

  `dependencies` = [('djmessenger', '0002_callback_fbuserprofile_getstartedbutton_persistentmenu')]
  `operations` = [<CreateModel name='UserLocation', options={'get_latest_by': 'date_created'}, fields=[('id', <django.db.models.fields.AutoField>), ('latitude', <django.db.models.fields.DecimalField>), ('longitude', <django.db.models.fields.DecimalField>), ('timestamp', <django.db.models.fields.BigIntegerField>), ('url', <django.db.models.fields.URLField>), ('mid', <django.db.models.fields.CharField>), ('seq', <django.db.models.fields.IntegerField>), ('date_created', <django.db.models.fields.DateTimeField>), ('user', <django.db.models.fields.related.ForeignKey>)]>]

## djmessenger.migrations.0004_auto_20160823_2245 module

class `djmessenger.migrations.0004_auto_20160823_2245.` `Migration`(name, app_label)

  Bases: `django.db.migrations.migration.Migration`

  `dependencies` = [('djmessenger', '0003_userlocation')]
  `operations` = [<AlterModelTable name='fbuserprofile', table='djm_user'>, <AlterModelTable name='getstartedbutton', table='db_getstarted'>, <AlterModelTable name='greetings', table='djm_greetings'>, <AlterModelTable name='persistentmenu', table='djm_persistentmenu'>, <AlterModelTable name='userlocation', table='djm_userlocation'>]

## djmessenger.migrations.0005_auto_20160823_2249 module

class `djmessenger.migrations.0005_auto_20160823_2249.` `Migration`(name, app_label)

  Bases: `django.db.migrations.migration.Migration`

  `dependencies` = [('djmessenger', '0004_auto_20160823_2245')]
  `operations` = [<CreateModel name='RawBody', options={'db_table': 'djm_rawbody'}, fields=[('id', <django.db.models.fields.AutoField>), ('raw', <django.db.models.fields.TextField>)]>, <DeleteModel name='Callback'>]

## djmessenger.migrations.0006_auto_20160823_2337 module

class `djmessenger.migrations.0006_auto_20160823_2337.` `Migration`(name, app_label)

  Bases: `django.db.migrations.migration.Migration`

  `dependencies` = [('djmessenger', '0005_auto_20160823_2249')]
  `operations` = [<CreateModel name='Messaging', fields=[('id', <django.db.models.fields.AutoField>), ('body', <django.db.models.fields.TextField>), ('type', <django.db.models.fields.CharField>)]>, <DeleteModel name='RawBody'>]

## djmessenger.migrations.0007_auto_20160823_2348 module

class `djmessenger.migrations.0007_auto_20160823_2348.` `Migration`(name, app_label)

  Bases: `django.db.migrations.migration.Migration`

  `dependencies` = [('djmessenger', '0006_auto_20160823_2337')]
  `operations` = [<AlterModelTable name='messaging', table='djm_messaging'>]

## djmessenger.migrations.0008_auto_20160824_0519 module

class `djmessenger.migrations.0008_auto_20160824_0519.` `Migration`(name, app_label)

  Bases: `django.db.migrations.migration.Migration`

  `dependencies` = [('djmessenger', '0007_auto_20160823_2348')]
  `operations` = [<AlterField name='first_name', field=<django.db.models.fields.CharField>, model_name='fbuserprofile'>, <AlterField name='gender', field=<django.db.models.fields.CharField>, model_name='fbuserprofile'>, <AlterField name='is_active', field=<django.db.models.fields.BooleanField>, model_name='fbuserprofile'>, <AlterField name='last_name', field=<django.db.models.fields.CharField>, model_name='fbuserprofile'>, <AlterField name='locale', field=<django.db.models.fields.CharField>, model_name='fbuserprofile'>, <AlterField name='profile_pic', field=<django.db.models.fields.TextField>, model_name='fbuserprofile'>, <AlterField name='psid', field=<django.db.models.fields.CharField>, model_name='fbuserprofile'>, <AlterField name='timezone', field=<django.db.models.fields.SmallIntegerField>, model_name='fbuserprofile'>, <AlterField name='text', field=<django.db.models.fields.CharField>, model_name='greetings'>, <AlterField name='body', field=<django.db.models.fields.TextField>, model_name='messaging'>, <AlterField name='type', field=<django.db.models.fields.CharField>, model_name='messaging'>, <AlterField name='title', field=<django.db.models.fields.CharField>, model_name='persistentmenu'>, <AlterField name='latitude', field=<django.db.models.fields.DecimalField>, model_name='userlocation'>, <AlterField name='longitude', field=<django.db.models.fields.DecimalField>, model_name='userlocation'>, <AlterField name='mid', field=<django.db.models.fields.CharField>, model_name='userlocation'>, <AlterField name='seq', field=<django.db.models.fields.IntegerField>, model_name='userlocation'>, <AlterField name='timestamp', field=<django.db.models.fields.BigIntegerField>, model_name='userlocation'>, <AlterField name='url', field=<django.db.models.fields.URLField>, model_name='userlocation'>, <AlterField name='user', field=<django.db.models.fields.related.ForeignKey>, model_name='userlocation'>]

## djmessenger.migrations.0009_auto_20160824_0625 module

class `djmessenger.migrations.0009_auto_20160824_0625.` `Migration`(name, app_label)

  Bases: `django.db.migrations.migration.Migration`

  `dependencies` = [('djmessenger', '0008_auto_20160824_0519')]
  `operations` = [<AddField name='thumbups', field=<django.db.models.fields.BigIntegerField>, model_name='fbuserprofile'>, <AlterField name='first_name', field=<django.db.models.fields.CharField>, model_name='fbuserprofile'>, <AlterField name='gender', field=<django.db.models.fields.CharField>, model_name='fbuserprofile'>, <AlterField name='is_active', field=<django.db.models.fields.BooleanField>, model_name='fbuserprofile'>, <AlterField name='last_name', field=<django.db.models.fields.CharField>, model_name='fbuserprofile'>, <AlterField name='locale', field=<django.db.models.fields.CharField>, model_name='fbuserprofile'>, <AlterField name='profile_pic', field=<django.db.models.fields.TextField>, model_name='fbuserprofile'>, <AlterField name='psid', field=<django.db.models.fields.CharField>, model_name='fbuserprofile'>, <AlterField name='timezone', field=<django.db.models.fields.SmallIntegerField>, model_name='fbuserprofile'>, <AlterField name='body', field=<django.db.models.fields.TextField>, model_name='messaging'>, <AlterField name='type', field=<django.db.models.fields.CharField>, model_name='messaging'>, <AlterField name='type', field=<django.db.models.fields.CharField>, model_name='persistentmenu'>, <AlterField name='latitude', field=<django.db.models.fields.DecimalField>, model_name='userlocation'>, <AlterField name='longitude', field=<django.db.models.fields.DecimalField>, model_name='userlocation'>, <AlterField name='mid', field=<django.db.models.fields.CharField>, model_name='userlocation'>, <AlterField name='seq', field=<django.db.models.fields.IntegerField>, model_name='userlocation'>, <AlterField name='timestamp', field=<django.db.models.fields.BigIntegerField>, model_name='userlocation'>, <AlterField name='url', field=<django.db.models.fields.URLField>, model_name='userlocation'>, <AlterField name='user', field=<django.db.models.fields.related.ForeignKey>, model_name='userlocation'>]

## djmessenger.migrations.0010_auto_20160824_0649 module

class `djmessenger.migrations.0010_auto_20160824_0649.` `Migration`(name, app_label)

  Bases: `django.db.migrations.migration.Migration`

  `dependencies` = [('djmessenger', '0009_auto_20160824_0625')]
  `operations` = [<AlterModelTable name='getstartedbutton', table='djm_getstarted'>]

## djmessenger.migrations.0011_sending module

class `djmessenger.migrations.0011_sending.` `Migration`(name, app_label)

  Bases: `django.db.migrations.migration.Migration`

  `dependencies` = [('djmessenger', '0010_auto_20160824_0649')]
  `operations` = [<CreateModel name='Sending', options={'db_table': 'djm_sending'}, fields=[('id', <django.db.models.fields.AutoField>), ('date_sent', <django.db.models.fields.DateTimeField>), ('data', <django.db.models.fields.TextField>), ('type', <django.db.models.fields.CharField>), ('response', <django.db.models.fields.TextField>), ('status_code', <django.db.models.fields.IntegerField>), ('recipient', <django.db.models.fields.related.ForeignKey>)]>]

## djmessenger.migrations.0012_auto_20160825_0718 module

class `djmessenger.migrations.0012_auto_20160825_0718.` `Migration`(name, app_label)

  Bases: `django.db.migrations.migration.Migration`

  `dependencies` = [('djmessenger', '0011_sending')]
  `operations` = [<AlterField name='response', field=<django.db.models.fields.TextField>, model_name='sending'>, <AlterField name='status_code', field=<django.db.models.fields.IntegerField>, model_name='sending'>]

## djmessenger.migrations.0013_auto_20160829_0510 module

class `djmessenger.migrations.0013_auto_20160829_0510.` `Migration`(name, app_label)

  Bases: `django.db.migrations.migration.Migration`

  `dependencies` = [('djmessenger', '0012_auto_20160825_0718')]
  `operations` = [<DeleteModel name='GetStartedButton'>, <DeleteModel name='Greetings'>, <DeleteModel name='PersistentMenu'>]

## djmessenger.migrations.0014_auto_20161110_1856 module

class `djmessenger.migrations.0014_auto_20161110_1856.` `Migration`(name, app_label)

  Bases: `django.db.migrations.migration.Migration`

  `dependencies` = [('djmessenger', '0013_auto_20160829_0510')]
  `operations` = [<RenameModel old_name='Sending', new_name='Reply'>, <AlterModelTable name='reply', table='djm_reply'>]

## Module contents